@@ -2,7 +2,7 @@
   filterkmail_maildir.cpp  -  Kmail maildir mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,10 +38,7 @@ FilterKMail_maildir::FilterKMail_maildir()
 }
 
 /** Destructor. */
-FilterKMail_maildir::~FilterKMail_maildir()
-{
-    delete d;
-}
+FilterKMail_maildir::~FilterKMail_maildir() = default;
 
 /** Recursive import of KMail maildir. */
 void FilterKMail_maildir::import()
@@ -135,7 +132,8 @@ void FilterKMail_maildir::importFiles(const QString &dirName)
 
     QDir importDir(dirName);
     const QStringList files = importDir.entryList(QStringList(QStringLiteral("[^\\.]*")), QDir::Files, QDir::Name);
-    int currentFile = 1, numFiles = files.size();
+    int currentFile = 1;
+    int numFiles = files.size();
     QStringList::ConstIterator filesEnd(files.constEnd());
 
     for (QStringList::ConstIterator mailFile = files.constBegin(); mailFile != filesEnd; ++mailFile, ++currentFile) {
